package VMOMI::HostSystemConnectionState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
